==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsGlobalConfigurationInputLossBehavior.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property blackFrameMsec
 * @property inputLossImageColor
 * @property inputLossImageSlate
 * @property inputLossImageType
 * @property repeatFrameMsec
 */
public data class ChannelEncoderSettingsGlobalConfigurationInputLossBehavior(
    public val blackFrameMsec: Int? = null,
    public val inputLossImageColor: String? = null,
    public val inputLossImageSlate:
    ChannelEncoderSettingsGlobalConfigurationInputLossBehaviorInputLossImageSlate? = null,
    public val inputLossImageType: String? = null,
    public val repeatFrameMsec: Int? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsGlobalConfigurationInputLossBehavior):
            ChannelEncoderSettingsGlobalConfigurationInputLossBehavior =
            ChannelEncoderSettingsGlobalConfigurationInputLossBehavior(
                blackFrameMsec = javaType.blackFrameMsec().map({ args0 -> args0 }).orElse(null),
                inputLossImageColor = javaType.inputLossImageColor().map({ args0 -> args0 }).orElse(null),
                inputLossImageSlate = javaType.inputLossImageSlate().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsGlobalConfigurationInputLossBehaviorInputLossImageSlate.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                inputLossImageType = javaType.inputLossImageType().map({ args0 -> args0 }).orElse(null),
                repeatFrameMsec = javaType.repeatFrameMsec().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelEncoderSettingsGlobalConfigurationInputLossBehavior.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property blackFrameMsec
 * @property inputLossImageColor
 * @property inputLossImageSlate
 * @property inputLossImageType
 * @property repeatFrameMsec
 */
public data class ChannelEncoderSettingsGlobalConfigurationInputLossBehavior(
    public val blackFrameMsec: Int? = null,
    public val inputLossImageColor: String? = null,
    public val inputLossImageSlate: ChannelEncoderSettingsGlobalConfigurationInputLossBehaviorInputLossImageSlate? = null,
    public val inputLossImageType: String? = null,
    public val repeatFrameMsec: Int? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelEncoderSettingsGlobalConfigurationInputLossBehavior): ChannelEncoderSettingsGlobalConfigurationInputLossBehavior =
            ChannelEncoderSettingsGlobalConfigurationInputLossBehavior(
                blackFrameMsec = javaType.blackFrameMsec().map({ args0 -> args0 }).orElse(null),
                inputLossImageColor = javaType.inputLossImageColor().map({ args0 -> args0 }).orElse(null),
                inputLossImageSlate = javaType.inputLossImageSlate().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.medialive.kotlin.outputs.ChannelEncoderSettingsGlobalConfigurationInputLossBehaviorInputLossImageSlate.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                inputLossImageType = javaType.inputLossImageType().map({ args0 -> args0 }).orElse(null),
                repeatFrameMsec = javaType.repeatFrameMsec().map({ args0 -> args0 }).orElse(null),
            )
    }
}
